==> jmx-addons-snmp-1.1.0-sources.jar: org/adeptnet/jmx/addons/snmp/BeanPDU.java <==
/*
 * Copyright 2014 Francois Steyn - Adept Internet (PTY) LTD (francois.s@adept.co.za).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.adeptnet.jmx.addons.snmp;

import java.util.HashMap;
import java.util.Map;
import org.snmp4j.PDU;

/**
 *
 * @author Francois Steyn - Adept Internet (PTY) LTD (francois.s@adept.co.za)
 */
public class BeanPDU {

    private final Map<String, Record> pdus = new HashMap<>();

    protected Map<String, Record> getMap() {
        return pdus;
    }

    public boolean hasRecord(final String reference) {
        return pdus.containsKey(reference);
    }

    public Record getRecord(final String reference) {
        return pdus.get(reference).withLastUsed();
    }

    public void setRecord(final String reference, final PDU pdu) {
        final Record record = new Record(pdu).withLastUsed();
        pdus.put(reference, record);
    }

    public class Record {

        private final PDU pdu;
        private long lastUsed = 0;

        public Record(PDU pdu) {
            this.pdu = pdu;
        }

        public PDU getPdu() {
            return pdu;
        }

        public long getLastUsed() {
            return lastUsed;
        }

        public Record withLastUsed() {
            lastUsed = System.currentTimeMillis();
            return this;
        }

    }

}

==> jmx-addons-snmp-1.2.1-sources.jar: org/adeptnet/jmx/addons/snmp/BeanPDU.java <==
/*
 * Copyright 2014 Francois Steyn - Adept Internet (PTY) LTD (francois.s@adept.co.za).
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.adeptnet.jmx.addons.snmp;

import java.util.HashMap;
import java.util.Map;
import org.snmp4j.PDU;

/**
 *
 * @author Francois Steyn - Adept Internet (PTY) LTD (francois.s@adept.co.za)
 */
public class BeanPDU {

    private final Map<String, Record> pdus = new HashMap<>();

    protected Map<String, Record> getMap() {
        return pdus;
    }

    public boolean hasRecord(final String reference) {
        return pdus.containsKey(reference);
    }

    public Record getRecord(final String reference) {
        return pdus.get(reference).withLastUsed();
    }

    public void setRecord(final String reference, final PDU pdu) {
        final Record record = new Record(pdu).withLastUsed();
        pdus.put(reference, record);
    }

    public void setRecord(final String reference, final Record record) {
        final Record r = new Record(record.getPdu(), record.getCreated()).withLastUsed();
        pdus.put(reference, r);
    }

    public class Record {

        private final PDU pdu;
        private long lastUsed = 0;
        private final long created;

        public Record(final PDU pdu, final long created) {
            this.pdu = pdu;
            this.created = created;
        }

        public Record(final PDU pdu) {
            this(pdu, System.currentTimeMillis());
        }

        public PDU getPdu() {
            return pdu;
        }

        public long getLastUsed() {
            return lastUsed;
        }

        public Record withLastUsed() {
            lastUsed = System.currentTimeMillis();
            return this;
        }

        public long getCreated() {
            return created;
        }

    }

}
